@@ -1,4 +1,4 @@
-use 5.008001;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ use base 'Exporter';
 our @EXPORT_OK = qw/encode decode/;
 
 use version;
-our $VERSION = 'v1.2.2';
+our $VERSION = 'v1.4.0';
 
 use Carp;
 use Config;
@@ -641,7 +641,7 @@ BSON - BSON serialization and deserialization
 
 =head1 VERSION
 
-version v1.2.2
+version v1.4.0
 
 =head1 SYNOPSIS
 
@@ -1149,7 +1149,7 @@ Stefan G. <minimalist@lavabit.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Eric Daniels Olivier Duclos Pat Gunn Yury Zavarin Oleg Kostyuk
+=for stopwords Eric Daniels Olivier Duclos Pat Gunn Petr Písař Yury Zavarin Oleg Kostyuk
 
 =over 4
 
@@ -1167,6 +1167,10 @@ Pat Gunn <pgunn@mongodb.com>
 
 =item *
 
+Petr Písař <ppisar@redhat.com>
+
+=item *
+
 Yury Zavarin <yury.zavarin@gmail.com>
 
 =item *
@@ -1177,7 +1181,7 @@ Oleg Kostyuk <cub@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Stefan G. and MongoDB, Inc.
+This software is Copyright (c) 2017 by Stefan G. and MongoDB, Inc.
 
 This is free software, licensed under:
 
