@@ -1,4 +1,4 @@
-use 5.008001;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -6,7 +6,7 @@ package BSON::Double;
 # ABSTRACT: BSON type wrapper for Double
 
 use version;
-our $VERSION = 'v1.2.2';
+our $VERSION = 'v1.4.0';
 
 use Carp;
 
@@ -26,9 +26,9 @@ has 'value' => (
 use namespace::clean -except => 'meta';
 
 use constant {
-    nInf  => unpack("d",pack("H*","000000000000f0ff")),
-    pInf  => unpack("d",pack("H*","000000000000f07f")),
-    NaN   => unpack("d",pack("H*","000000000000f8ff")),
+    nInf  => unpack("d<",pack("H*","000000000000f0ff")),
+    pInf  => unpack("d<",pack("H*","000000000000f07f")),
+    NaN   => unpack("d<",pack("H*","000000000000f8ff")),
 };
 
 sub BUILD {
@@ -92,7 +92,7 @@ BSON::Double - BSON type wrapper for Double
 
 =head1 VERSION
 
-version v1.2.2
+version v1.4.0
 
 =head1 SYNOPSIS
 
@@ -166,7 +166,7 @@ Stefan G. <minimalist@lavabit.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Stefan G. and MongoDB, Inc.
+This software is Copyright (c) 2017 by Stefan G. and MongoDB, Inc.
 
 This is free software, licensed under:
 
