@@ -1,4 +1,4 @@
-use 5.008001;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -6,7 +6,7 @@ package BSON::Time;
 # ABSTRACT: BSON type wrapper for date and time
 
 use version;
-our $VERSION = 'v1.2.2';
+our $VERSION = 'v1.4.0';
 
 use Carp qw/croak/;
 use Config;
@@ -43,7 +43,7 @@ sub BUILDARGS {
         else {
             $args{value} = Math::BigFloat->new(time());
             $args{value}->bmul(1000);
-            $args{value} = int($args{value});
+            $args{value} = $args{value}->as_number('zero');
         }
     }
     elsif ( $n == 1 ) {
@@ -53,7 +53,7 @@ sub BUILDARGS {
         if ( !$Config{use64bitint} && ref($args{value}) ne 'Math::BigInt' ) {
             $args{value} = Math::BigFloat->new(shift);
             $args{value}->bmul(1000);
-            $args{value} = int($args{value});
+            $args{value} = $args{value}->as_number('zero');
         }
         else {
             $args{value} = 1000 * shift;
@@ -73,7 +73,7 @@ sub BUILDARGS {
             if ( !$Config{use64bitint} && ref($args{value}) ne 'Math::BigInt' ) {
                 $args{value} = Math::BigFloat->new(shift);
                 $args{value}->bmul(1000);
-                $args{value} = int($args{value});
+                $args{value} = $args{value}->as_number('zero');
             }
             else {
                 $args{value} = 1000 * shift;
@@ -230,7 +230,7 @@ BSON::Time - BSON type wrapper for date and time
 
 =head1 VERSION
 
-version v1.2.2
+version v1.4.0
 
 =head1 SYNOPSIS
 
@@ -317,7 +317,7 @@ Stefan G. <minimalist@lavabit.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Stefan G. and MongoDB, Inc.
+This software is Copyright (c) 2017 by Stefan G. and MongoDB, Inc.
 
 This is free software, licensed under:
 
